summaryrefslogtreecommitdiffstats
path: root/src/eval.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/eval.c')
-rw-r--r--src/eval.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/eval.c b/src/eval.c
index 4bd45e9ceb..31dde2faed 100644
--- a/src/eval.c
+++ b/src/eval.c
@@ -393,7 +393,7 @@ eval_to_string(
/*
* Call eval_to_string() without using current local variables and using
* textlock. When "use_sandbox" is TRUE use the sandbox.
*/
char_u *
eval_to_string_safe(
@@ -407,11 +407,11 @@ eval_to_string_safe(
save_funccal(&funccal_entry);
if (use_sandbox)
++sandbox;
- ++textlock;
+ ++textwinlock;
retval = eval_to_string(arg, nextcmd, FALSE);
if (use_sandbox)
--sandbox;
- --textlock;
+ --textwinlock;
restore_funccal();
return retval;
}
@@ -576,7 +576,7 @@ eval_foldexpr(char_u *arg, int *cp)
++emsg_off;
if (use_sandbox)
++sandbox;
- ++textlock;
+ ++textwinlock;
*cp = NUL;
if (eval0(arg, &tv, NULL, TRUE) == FAIL)
retval = 0;
@@ -601,7 +601,7 @@ eval_foldexpr(char_u *arg, int *cp)
--emsg_off;
if (use_sandbox)
--sandbox;
- --textlock;
+ --textwinlock;
return (int)retval;
}
@@ -393,7 +393,7 @@ eval_to_string(
/*
* Call eval_to_string() without using current local variables and using
- * textlock. When "use_sandbox" is TRUE use the sandbox.
+ * textwinlock. When "use_sandbox" is TRUE use the sandbox.
*/
char_u *